# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sagemaker/training_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/sagemaker/training_job.proto',
  package='flyteidl.plugins.sagemaker',
  syntax='proto3',
  serialized_options=_b('Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n-flyteidl/plugins/sagemaker/training_job.proto\x12\x1a\x66lyteidl.plugins.sagemaker\"\xc3\x02\n\x16\x41lgorithmSpecification\x12\x39\n\ninput_mode\x18\x01 \x01(\x0e\x32%.flyteidl.plugins.sagemaker.InputMode\x12\x41\n\x0e\x61lgorithm_name\x18\x02 \x01(\x0e\x32).flyteidl.plugins.sagemaker.AlgorithmName\x12\x19\n\x11\x61lgorithm_version\x18\x03 \x01(\t\x12_\n\x12metric_definitions\x18\x04 \x03(\x0b\x32\x43.flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition\x1a/\n\x10MetricDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05regex\x18\x02 \x01(\t\"]\n\x11TrainingJobConfig\x12\x16\n\x0einstance_count\x18\x01 \x01(\x03\x12\x15\n\rinstance_type\x18\x02 \x01(\t\x12\x19\n\x11volume_size_in_gb\x18\x03 \x01(\x03\"U\n\x11StoppingCondition\x12\x1e\n\x16max_runtime_in_seconds\x18\x01 \x01(\x03\x12 \n\x18max_wait_time_in_seconds\x18\x02 \x01(\x03\"\xc5\x01\n\x0bTrainingJob\x12S\n\x17\x61lgorithm_specification\x18\x01 \x01(\x0b\x32\x32.flyteidl.plugins.sagemaker.AlgorithmSpecification\x12J\n\x13training_job_config\x18\x02 \x01(\x0b\x32-.flyteidl.plugins.sagemaker.TrainingJobConfig\x12\x15\n\rinterruptible\x18\x04 \x01(\x08*\x1f\n\tInputMode\x12\x08\n\x04\x46ILE\x10\x00\x12\x08\n\x04PIPE\x10\x01*(\n\rAlgorithmName\x12\n\n\x06\x43USTOM\x10\x00\x12\x0b\n\x07XGBOOST\x10\x01\x42\x35Z3github.com/lyft/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)

_INPUTMODE = _descriptor.EnumDescriptor(
  name='InputMode',
  full_name='flyteidl.plugins.sagemaker.InputMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PIPE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=785,
  serialized_end=816,
)
_sym_db.RegisterEnumDescriptor(_INPUTMODE)

InputMode = enum_type_wrapper.EnumTypeWrapper(_INPUTMODE)
_ALGORITHMNAME = _descriptor.EnumDescriptor(
  name='AlgorithmName',
  full_name='flyteidl.plugins.sagemaker.AlgorithmName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XGBOOST', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=818,
  serialized_end=858,
)
_sym_db.RegisterEnumDescriptor(_ALGORITHMNAME)

AlgorithmName = enum_type_wrapper.EnumTypeWrapper(_ALGORITHMNAME)
FILE = 0
PIPE = 1
CUSTOM = 0
XGBOOST = 1



_ALGORITHMSPECIFICATION_METRICDEFINITION = _descriptor.Descriptor(
  name='MetricDefinition',
  full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regex', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition.regex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=401,
)

_ALGORITHMSPECIFICATION = _descriptor.Descriptor(
  name='AlgorithmSpecification',
  full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_mode', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.input_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm_name', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.algorithm_name', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm_version', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.algorithm_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metric_definitions', full_name='flyteidl.plugins.sagemaker.AlgorithmSpecification.metric_definitions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ALGORITHMSPECIFICATION_METRICDEFINITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=401,
)


_TRAININGJOBCONFIG = _descriptor.Descriptor(
  name='TrainingJobConfig',
  full_name='flyteidl.plugins.sagemaker.TrainingJobConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_count', full_name='flyteidl.plugins.sagemaker.TrainingJobConfig.instance_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='flyteidl.plugins.sagemaker.TrainingJobConfig.instance_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume_size_in_gb', full_name='flyteidl.plugins.sagemaker.TrainingJobConfig.volume_size_in_gb', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=496,
)


_STOPPINGCONDITION = _descriptor.Descriptor(
  name='StoppingCondition',
  full_name='flyteidl.plugins.sagemaker.StoppingCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_runtime_in_seconds', full_name='flyteidl.plugins.sagemaker.StoppingCondition.max_runtime_in_seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_wait_time_in_seconds', full_name='flyteidl.plugins.sagemaker.StoppingCondition.max_wait_time_in_seconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=583,
)


_TRAININGJOB = _descriptor.Descriptor(
  name='TrainingJob',
  full_name='flyteidl.plugins.sagemaker.TrainingJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm_specification', full_name='flyteidl.plugins.sagemaker.TrainingJob.algorithm_specification', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='training_job_config', full_name='flyteidl.plugins.sagemaker.TrainingJob.training_job_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interruptible', full_name='flyteidl.plugins.sagemaker.TrainingJob.interruptible', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=783,
)

_ALGORITHMSPECIFICATION_METRICDEFINITION.containing_type = _ALGORITHMSPECIFICATION
_ALGORITHMSPECIFICATION.fields_by_name['input_mode'].enum_type = _INPUTMODE
_ALGORITHMSPECIFICATION.fields_by_name['algorithm_name'].enum_type = _ALGORITHMNAME
_ALGORITHMSPECIFICATION.fields_by_name['metric_definitions'].message_type = _ALGORITHMSPECIFICATION_METRICDEFINITION
_TRAININGJOB.fields_by_name['algorithm_specification'].message_type = _ALGORITHMSPECIFICATION
_TRAININGJOB.fields_by_name['training_job_config'].message_type = _TRAININGJOBCONFIG
DESCRIPTOR.message_types_by_name['AlgorithmSpecification'] = _ALGORITHMSPECIFICATION
DESCRIPTOR.message_types_by_name['TrainingJobConfig'] = _TRAININGJOBCONFIG
DESCRIPTOR.message_types_by_name['StoppingCondition'] = _STOPPINGCONDITION
DESCRIPTOR.message_types_by_name['TrainingJob'] = _TRAININGJOB
DESCRIPTOR.enum_types_by_name['InputMode'] = _INPUTMODE
DESCRIPTOR.enum_types_by_name['AlgorithmName'] = _ALGORITHMNAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AlgorithmSpecification = _reflection.GeneratedProtocolMessageType('AlgorithmSpecification', (_message.Message,), dict(

  MetricDefinition = _reflection.GeneratedProtocolMessageType('MetricDefinition', (_message.Message,), dict(
    DESCRIPTOR = _ALGORITHMSPECIFICATION_METRICDEFINITION,
    __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.AlgorithmSpecification.MetricDefinition)
    ))
  ,
  DESCRIPTOR = _ALGORITHMSPECIFICATION,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.AlgorithmSpecification)
  ))
_sym_db.RegisterMessage(AlgorithmSpecification)
_sym_db.RegisterMessage(AlgorithmSpecification.MetricDefinition)

TrainingJobConfig = _reflection.GeneratedProtocolMessageType('TrainingJobConfig', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOBCONFIG,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJobConfig)
  ))
_sym_db.RegisterMessage(TrainingJobConfig)

StoppingCondition = _reflection.GeneratedProtocolMessageType('StoppingCondition', (_message.Message,), dict(
  DESCRIPTOR = _STOPPINGCONDITION,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.StoppingCondition)
  ))
_sym_db.RegisterMessage(StoppingCondition)

TrainingJob = _reflection.GeneratedProtocolMessageType('TrainingJob', (_message.Message,), dict(
  DESCRIPTOR = _TRAININGJOB,
  __module__ = 'flyteidl.plugins.sagemaker.training_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.sagemaker.TrainingJob)
  ))
_sym_db.RegisterMessage(TrainingJob)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
